Examples
=================================

.. note::

    All user examples `available on Github <https://github.com/IBM/ibm-generative-ai/tree/main/examples/user>`_ !

.. toctree::
   :maxdepth: 4

   examples.user
